---
title: Investigating the Impact of Lunar Cycles on Plant Growth
date: 2024-10-26
authors:
  - name:  Alice Green
    affiliations: [University of Nature]
  - name: Bob Blue
    affiliations: [Institute of Botanical Studies]
export:
  - format: pdf
    template: ..
---

# Introduction

:::{figure} ./figures/overall_growth.png
:label: fig:overall-growth
:width: 100%

Comparison of overall growth between the "Lunar" and "Control" groups over the 56-day period.  Error bars represent the standard deviation of the mean.
:::

The relationship between lunar cycles and plant growth has been a topic of interest for centuries, with various cultures attributing agricultural success or failure to the moon's phases. This study investigates the potential correlation between lunar phases and the growth rate of common bean plants (*Phaseolus vulgaris*).  While anecdotal evidence abounds, rigorous scientific studies are less common. This paper aims to contribute to a more data-driven understanding of this phenomenon.

# Methods

## Experimental Setup

Two groups of 50 bean seedlings, genetically identical, were cultivated in a controlled environment within a greenhouse.  The first group, designated the "Lunar" group, was exposed to ambient light conditions, reflecting the natural lunar cycle. The second group, the "Control" group, was exposed to a constant light cycle, with no variation mimicking the lunar phases.

All other environmental parameters, including temperature, humidity, and watering schedule, were strictly controlled and maintained identically between both groups.  The experiment spanned a period of two lunar cycles (approximately 56 days).

## Measurements

Plant height was measured every three days for each individual seedling, starting from the first day of germination. The measurements were carried out using a calibrated ruler, with accuracy to the nearest millimeter. Data were recorded in a centralized spreadsheet for subsequent analysis.

## Statistical Analysis

The mean growth rate was calculated for each group. To compare the growth rates between the "Lunar" and "Control" groups, we performed a two-sample t-test. A p-value of less than 0.05 was considered statistically significant. Additionally, growth rates during each lunar phase (new moon, first quarter, full moon, third quarter) were analyzed separately.

# Results

## Overall Growth

As illustrated in @fig:overall-growth, both groups of bean plants exhibited significant growth over the experimental period. The "Lunar" group showed a mean growth of 35.2 cm (SD = 4.5 cm) whereas the control group grew 34.8cm (SD=4.2cm). The difference was not statistically significant (p > 0.05).

## Growth by Lunar Phase

:::{figure} ./figures/growth_by_phase.png
:label: fig:growth-by-phase
:width: 100%

Mean growth rate during each lunar phase. Error bars represent the standard error of the mean.
:::

The analysis of growth rates during each lunar phase, presented in @fig:growth-by-phase, shows a slight trend towards increased growth during the full moon phase for the "Lunar" group.  However, this difference was also not statistically significant. The new moon phase showed a slightly smaller growth in the lunar group.

# Discussion

Our results do not provide strong evidence for a direct, statistically significant effect of lunar cycles on the growth rate of bean plants. While there were subtle variations observed between groups and phases, these differences were not sufficient to reject the null hypothesis.

It's important to acknowledge that our study was limited to a single species, and it is possible that other plant species may be more sensitive to lunar influences.  Furthermore, other factors, such as soil composition and nutrient availability, were not varied in this experiment and could be contributing factors that would influence the interaction of lunar cycles.

# Future Directions

Future research could focus on:

*   Investigating a wider variety of plant species.
*   Longer experimental durations to observe potential long-term effects.
*   Examining the effects of specific wavelengths of moonlight.
*   Exploring potential interactions between lunar cycles and other environmental factors.

# Conclusion

While the influence of the moon on agricultural practices has deep cultural roots, our results suggest that, at least for bean plants, the impact of lunar phases on growth is minimal under controlled conditions.  More research is needed to fully understand the potential interactions between lunar cycles and plant physiology.

# Appendix

Table 1 : Raw Data

| Plant ID | Day 1 | Day 3 | Day 6 | Day ... |
|---|---|---|---|---|
| Lunar 1 | 1 | 2.5 | 4.2 | ... |
| Lunar 2 | 1.2 | 2.8 | 4.5 | ... |
| ... | ... | ... | ... | ... |
| Control 1 | 1 | 2.6 | 4.1 | ... |
| ... | ... | ... | ... | ... |
